==> moodle-1.4.3-pgsql.tgz: moodle/lang/ko/chat.php <==
<?PHP // $Id$ 
      // chat.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['beep'] = 'ȣ';
$string['chatintro'] = 'Ӹ';
$string['chatname'] = 'ȭ ̸';
$string['chatreport'] = 'ȭ ';
$string['chattime'] = '  ð';
$string['configoldping'] = 'ڰ ƹ      ȭ   ұ?';
$string['configrefreshroom'] = ' ʸ ȭ ұ? ( ʾȿ).  ª ð ϸ  ̰,   ȭ     ϰ  ɸ ˴ϴ.';
$string['configrefreshuserlist'] = ' ʸ ڵ  ұ? ';
$string['currentchats'] = 'Ȱ ȭ';
$string['currentusers'] = ' ڵ';
$string['deletesession'] = 'ȭ մϴ.';
$string['deletesessionsure'] = ' ȭ ұ?';
$string['donotusechattime'] = ' ȭ 뵵  .';
$string['enterchat'] = 'ȭ Ͻ÷ ⸦ Ŭ!';
$string['errornousers'] = ' ڵ ã  !';
$string['helpchatting'] = 'ȭ  ';
$string['idle'] = '';
$string['messagebeepseveryone'] = '$a   !';
$string['messagebeepsyou'] = '$a ޽  !';
$string['messageenter'] = '$a ȭ濡 ';
$string['messageexit'] = '$a ȭ ';
$string['messages'] = '޽';
$string['modulename'] = 'ȭ';
$string['modulenameplural'] = 'ȭ';
$string['neverdeletemessages'] = '޽  ʱ';
$string['nextsession'] = '  ȭ';
$string['nomessages'] = ' ޽ ';
$string['repeatdaily'] = '  ð';
$string['repeatnone'] = 'ݺ ,  ð ϱ';
$string['repeattimes'] = 'ȭ Ǯ';
$string['repeatweekly'] = '  ð';
$string['savemessages'] = ' ޽ ϱ';
$string['seesession'] = 'ȭ ';
$string['sessions'] = 'ȭ';
$string['strftimemessage'] = '%%H:%%M';
$string['studentseereports'] = '   ȭ   ֽϴ.';
$string['thischarset'] = 'euc-kr';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = '&#54620;&#44397;&#50612;';
$string['viewreport'] = ' ȭ  ';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ko/chat.php <==
<?PHP // $Id$



$string['beep'] = 'ȣ';
$string['chatintro'] = 'Ӹ';
$string['chatname'] = 'ȭ ̸';
$string['chatreport'] = 'ȭ ';
$string['chattime'] = '  ð';
$string['configmethod'] = 'Ϲ ä  ڵ Ģ    ʿ մϴ. ̰ Ұ ƴѰͰ  ۾ ʿ ,  ȭڵ 󿡼  ڷḦ   ֽϴ.';
$string['configoldping'] = 'ڰ ƹ      ȭ   ұ?';
$string['configrefreshroom'] = ' ʸ ȭ ұ? ( ʾȿ).  ª ð ϸ  ̰,   ȭ     ϰ  ɸ ˴ϴ.';
$string['configrefreshuserlist'] = ' ʸ ڵ  ұ? ';
$string['configserverhost'] = ' ڸ';
$string['configserverip'] = 'ڸ   IPּ';
$string['configservermax'] = 'ִ   ';
$string['configserverport'] = '  Ʈ';
$string['currentchats'] = 'Ȱ ȭ';
$string['currentusers'] = ' ڵ';
$string['deletesession'] = 'ȭ մϴ.';
$string['deletesessionsure'] = ' ȭ ұ?';
$string['donotusechattime'] = ' ȭ 뵵  .';
$string['enterchat'] = 'ȭ Ͻ÷ ⸦ Ŭ!';
$string['errornousers'] = ' ڵ ã  !';
$string['explaingeneralconfig'] = '̷ õ ׻ ȿ Ÿϴ.';
$string['explainmethoddaemon'] = '̷     ȭ  \"äü
\" ϿԴϴ.';
$string['explainmethodnormal'] = '̷     ȭ  \"Ϲ \"
 ϿԴϴ.';
$string['generalconfig'] = 'ü ';
$string['helpchatting'] = 'ȭ  ';
$string['idle'] = '';
$string['messagebeepseveryone'] = '$a   !';
$string['messagebeepsyou'] = '$a ޽  !';
$string['messageenter'] = '$a ȭ濡 ';
$string['messageexit'] = '$a ȭ ';
$string['messages'] = '޽';
$string['methoddaemon'] = 'ä ';
$string['methodnormal'] = 'Ϲ ';
$string['modulename'] = 'ȭ';
$string['modulenameplural'] = 'ȭ';
$string['neverdeletemessages'] = '޽  ʱ';
$string['nextsession'] = '  ȭ';
$string['noguests'] = 'ȭ ڰ ϴ.';
$string['nomessages'] = ' ޽ ';
$string['repeatdaily'] = '  ð';
$string['repeatnone'] = 'ݺ ,  ð ϱ';
$string['repeattimes'] = 'ȭ Ǯ';
$string['repeatweekly'] = '  ð';
$string['savemessages'] = ' ޽ ϱ';
$string['seesession'] = 'ȭ ';
$string['sessions'] = 'ȭ';
$string['strftimemessage'] = '%%H:%%M';
$string['studentseereports'] = '   ȭ   ֽϴ.';
$string['viewreport'] = ' ȭ  ';
?>
